@@ -26,20 +26,12 @@ EnabledConnections::EnabledConnections(QObject* parent)
     , m_networkingEnabled(NetworkManager::isNetworkingEnabled())
     , m_wirelessEnabled(NetworkManager::isWirelessEnabled())
     , m_wirelessHwEnabled(NetworkManager::isWirelessHardwareEnabled())
-#if !NM_CHECK_VERSION(1, 2, 0)
-    , m_wimaxEnabled(NetworkManager::isWimaxEnabled())
-    , m_wimaxHwEnabled(NetworkManager::isWimaxHardwareEnabled())
-#endif
     , m_wwanEnabled(NetworkManager::isWwanEnabled())
     , m_wwanHwEnabled(NetworkManager::isWwanHardwareEnabled())
 {
     connect(NetworkManager::notifier(), &NetworkManager::Notifier::networkingEnabledChanged, this, &EnabledConnections::onNetworkingEnabled);
     connect(NetworkManager::notifier(), &NetworkManager::Notifier::wirelessEnabledChanged, this, &EnabledConnections::onWirelessEnabled);
     connect(NetworkManager::notifier(), &NetworkManager::Notifier::wirelessHardwareEnabledChanged, this, &EnabledConnections::onWirelessHwEnabled);
-#if !NM_CHECK_VERSION(1, 2, 0)
-    connect(NetworkManager::notifier(), &NetworkManager::Notifier::wimaxEnabledChanged, this, &EnabledConnections::onWimaxEnabled);
-    connect(NetworkManager::notifier(), &NetworkManager::Notifier::wimaxHardwareEnabledChanged, this, &EnabledConnections::onWimaxHwEnabled);
-#endif
     connect(NetworkManager::notifier(), &NetworkManager::Notifier::wwanEnabledChanged, this, &EnabledConnections::onWwanEnabled);
     connect(NetworkManager::notifier(), &NetworkManager::Notifier::wwanHardwareEnabledChanged, this, &EnabledConnections::onWwanHwEnabled);
 }
@@ -63,18 +55,6 @@ bool EnabledConnections::isWirelessHwEnabled() const
     return m_wirelessHwEnabled;
 }
 
-#if !NM_CHECK_VERSION(1, 2, 0)
-bool EnabledConnections::isWimaxEnabled() const
-{
-    return m_wimaxEnabled;
-}
-
-bool EnabledConnections::isWimaxHwEnabled() const
-{
-    return m_wimaxHwEnabled;
-}
-#endif
-
 bool EnabledConnections::isWwanEnabled() const
 {
     return m_wwanEnabled;
@@ -103,20 +83,6 @@ void EnabledConnections::onWirelessHwEnabled(bool enabled)
     Q_EMIT wirelessHwEnabled(enabled);
 }
 
-#if !NM_CHECK_VERSION(1, 2, 0)
-void EnabledConnections::onWimaxEnabled(bool enabled)
-{
-    m_wimaxEnabled = enabled;
-    Q_EMIT wimaxEnabled(enabled);
-}
-
-void EnabledConnections::onWimaxHwEnabled(bool enabled)
-{
-    m_wimaxHwEnabled = enabled;
-    Q_EMIT wimaxHwEnabled(enabled);
-}
-#endif
-
 void EnabledConnections::onWwanEnabled(bool enabled)
 {
     m_wwanEnabled = enabled;
